\name{analyze.all.GO}
\alias{analyze.all.GO}
\title{
General GO enrichment analysis
}
\description{
Performs a general GO enrichment analysis for a set of genes identified by their ids and for all the terms in a given GO aspect. The analysis is performed using the Fisher's exact test. Optionally filters results per a False Discovery Rate (FDR).
}
\usage{
analyze.all.GO(ids, aspect = "BP", only.FDR.le = NULL)
}
\arguments{
  \item{ids}{
(\code{numeric}) Set of target gene identifiers to form the 2 x 2 contingency table to be tested.
}
  \item{aspect}{
Must be one of the valid aspects of GO: "BP" (Biological Process) or "CC" (Cell Component) or "MF" (Molecular function).
}
  \item{only.FDR.le}{
\code{NULL} (if no filtering of the results is desired) or a number between 0 and 1 with the threshold for the maximum False Discovery Rate (FDR) to be reported.
}
}
\details{
Using the \code{ids} and EACH ONE of the terms of the GO aspect, a contingency table is formed by crossing the criteria Annotated and Target (in each case FALSE or TRUE) and the resulting 2 x 2 contingency table is analyzed using Fisher's exact test under the null hypothesis of criteria independence. Results are returned in a \code{data.frame} with rows corresponding to each GO aspect (if not filtered by FDR, i.e., if \code{only.FDR.le = NULL} (the default) or only with rows that fulfill the FDR asked. If there are no rows that fulfill the FDR criterion, a \code{data.frame} with 0 rows is returned without warning.
}
\value{
A data.frame with the following columns
\item{aspect }{GO aspect analyzed.}
\item{aspect.id }{Numerical identifier of the GO aspect.}
\item{desc }{Description of the GO aspect analyzed.}
\item{odds }{Odds ratio for the contingency table.}
\item{P }{P value for the test of independence.}
\item{AnnTarg }{Annotated with aspect and in Target set}
\item{NotAnnTarg }{Not Annotated with aspect and in Target set}
\item{AnnNotTarg }{Annotated with aspect and Not in Target set}
\item{NotAnnNotTarg }{Not Annotated with aspect and Not in Target set}
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
Running can take some time, be patient. The total of genes taken into account corresponds to the total of genes with valid expression in the data and which are annotated in the GO aspect.
}
\seealso{
\code{\link{analyze.GO}}, \code{\link{get.ids}}, \code{\link{get.GO.terms.by.desc}}, \code{\link{browse.GO}}.
}
\examples{
# A dummy set of ids that will give
# "significant" results.
my.temp.ids <- c(unique(get.genes.by.GO.desc(
"mitochondrial outer membrane translocase complex"
, only.aspect="CC")$id), gene$id[1:26])

# Calling the function with that set of ids
# and filtering by a minimum FDR of 1%
# (can take some time)
my.temp.res <- analyze.all.GO(ids=my.temp.ids,
aspect = "CC", only.FDR.le = 0.01)

# See some of the results
head(my.temp.res)
tail(my.temp.res)

# Clean temporary objects
rm(my.temp.ids, my.temp.res)
}
