\name{get.SEP}
\alias{get.SEP}
\title{
Obtains a SEP data frame
}
\description{
Obtains a Standardized Expression Profile (SEP) data frame with rows that fulfill various criteria determined by the input.
}
\usage{
get.SEP(ids, descr, acc.key, acc.type, model, ExistInAll,
 TimeMaxExp, isTF, coded.expr.level, previous.sep)
}
\arguments{
  \item{ids}{
\code{integer}. A vector with the gene identifiers (\code{id}) that must be present in the SEP.
}
  \item{descr}{
One or more words (character strings) that you want to be part of the \code{Prot.Desc} for the genes in the output.
}
  \item{acc.key}{
One or more \code{acc.key} (key for the accessions) that you want to be in the output SEP. 
}
  \item{acc.type}{
One or more \code{acc.type} (key for the accession types) that you want to be in the output SEP.
}
  \item{model}{
One or more \code{model} (key for SEP models) that you want to be in the output SEP.
}
  \item{ExistInAll}{
\code{logical}. If \code{TRUE} only cases of genes expressed in all 12 accession will be present in the output SEP.
}
  \item{TimeMaxExp}{
\code{numeric}. If present must be a vector of times where the maximum expression of the gene was reached, i.e., a time existent in the vector \code{DAA}, 0, 10, 20, 30, 40, 50 and or 60.
}
  \item{isTF}{
\code{logical}. If \code{TRUE} only genes annotated as Transcription Factors will be present in the output SEP.
}
  \item{coded.expr.level}{
\code{numeric} One or more coded expression levels, i.e., numbers 1, 2, 3, 4 and 5. Only genes with those coded expression levels will be present in the output SEP.
}
  \item{previous.sep}{
If \code{NULL} the SEP used for the selection will be the original \code{SEP} present in the package, otherwise this parameter must contain a valid SEP, possibly selected with a previous call to the function. In that case such SEP will be used for the selection.
}
}
\details{
This function can be used to select a subset of data for further analysis.
}
\value{
A SEP data frame containing rows that fulfill all criteria pass to the function in the input.
}
\references{
O. Martinez et al. (In preparation). An R package for data mining chili pepper fruit transcriptomes.
}
\author{
O. Martinez
}
\note{
This function can be used in the initial data mining steps to select sets of data to be employed in further analysis.
}

\seealso{
\code{\link{SEP}}, \code{\link{SEP.summary}}, \code{\link{SEPs.plot}}, \code{\link{analyze.2.SEPs}}, \code{\link{FPKM.expr}}.
}
\examples{
# Return NULL because there is no gene
# with the description pass to the function
get.SEP(descr="MyFavorite gene")

# Obtain a SEP with all the Transcription Factors that are
# expressed in all 12 accessions.
temp.TF.all <- get.SEP(ExistInAll = TRUE, isTF = TRUE)
# How many rows has that SEP?
nrow(temp.TF.all)

# Some characteristics of that SEP
length(unique(temp.TF.all$id)) # How many different genes?
table(temp.TF.all$acc.key) # Number of cases per accession

# Now, assume that we want the Transcription Factors
# which include in the description the character "WRKY"
# and are present only in wild accessions.
# Using the previous SEP we can obtain:
temp.TF.WRKY.W <- get.SEP(descr="WRKY", acc.type="W", 
previous.sep=temp.TF.all)
nrow(temp.TF.WRKY.W)

# Now assume that from that from the previous SEP we want only
# cases where the model is "DSSSSS", i.e., genes that are
# highly expressed in flower but then present an steady state
# along the remaining time intervals:
temp.TF.WRKY.W.DSSSSS <- get.SEP(model="DSSSSS", 
previous.sep=temp.TF.WRKY.W)

# See the resulting SEP
# (note that all cases have the same standardized expression)
temp.TF.WRKY.W.DSSSSS

# An alternative way to obtain "temp.TF.WRKY.W.DSSSSS" with
# a single call of get.SEP is:
temp.TF.WRKY.W.DSSSSS.2 <- get.SEP(descr="WRKY", acc.type="W", 
model="DSSSSS", ExistInAll=TRUE)
temp.TF.WRKY.W.DSSSSS.2

# Remove the objects that we created
rm(list=ls(patt='temp.TF'))
}
